Description Usage Arguments Details Examples
Retrieves the present daemon status
1 | dropbox_help(topic = NULL)
|
topic |
A |
Valid topics are:
| status | get current status of the dropboxd |
| throttle | set bandwidth limits for Dropbox |
| help | provide help |
| puburl | get public url of a file in your dropbox's public folder |
| stop | stop dropboxd |
| running | return whether dropbox is running |
| start | start dropboxd |
| filestatus | get current sync status of one or more files |
| ls | list directory contents with current sync status |
| autostart | automatically start dropbox at login |
| exclude | ignores/excludes a directory from syncing |
| lansync | enables or disables LAN sync |
| sharelink | get a shared link for a file in your dropbox |
| proxy | set proxy settings for Dropbox |
If NULL is supplied then the above index is printed.
1 2 3 4 5 6 7 8 | ## Not run:
# Get standard help table
dropbox_help()
# Request help with puburl
dropbox_help("puburl")
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.